/********************
 * 2004 Jalview Reengineered
 * Barton Group
 * Dundee University
 *
 * AM Waterhouse
 *******************/


package jalview.gui;

import jalview.gui.*;
import jalview.io.*;
import jalview.datamodel.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;


public class Desktop extends jalview.jbgui.GDesktop
{
  public static JDesktopPane desktop;
  static int openFrameCount = 0;
  static final int xOffset = 30, yOffset = 30;

  public Desktop()
  {
    Image image =null;
    try{
      java.net.URL url = getClass().getResource("/BartonGroupBanner.gif");
      if(url!=null)
      {
        image = java.awt.Toolkit.getDefaultToolkit().createImage(url);
        MediaTracker mt = new MediaTracker(this);
        mt.addImage(image, 0);
        mt.waitForID(0);
        setIconImage(image);
      }

    }catch(Exception ex){}

    setTitle("Jalview 2005");
    setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    setVisible(true);
    desktop = new JDesktopPane();
    setContentPane(desktop);
    desktop.setDragMode(JDesktopPane.OUTLINE_DRAG_MODE);

    Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
    int width = 1200, height = 800;
    if(screenSize.getWidth()<width)
      width = screenSize.width;
    if(screenSize.getHeight()<height)
      height = screenSize.height;

    setBounds( (int)(screenSize.width-width)/2,
               (int)(screenSize.height-height)/2,
              width ,
              height);


   /////////Add a splashscreen on startup
    JInternalFrame frame = new JInternalFrame();

    SplashScreen splash = new SplashScreen(frame, image);
    frame.setContentPane(splash);
    desktop.add(frame);
    frame.setVisible(true);
    openFrameCount++;
    try
    {
      frame.setSelected(true);
    }
    catch (java.beans.PropertyVetoException e)
    {}
    frame.setResizable(true);
    frame.setSize(845, 200);
    frame.setLocation( (int)((getWidth()-845) /2), (int)((getHeight()-240) /2));
    frame.setClosable(false);
    frame.setIconifiable(false);
    frame.setMaximizable(false);
    frame.setFrameIcon(null);

  }

  public static void addInternalFrame(final JInternalFrame frame, String title, int w, int h)
  {
   desktop.add(frame);
   frame.setVisible(true);
   openFrameCount++;
   try {
       frame.setSelected(true);
   } catch (java.beans.PropertyVetoException e) {}
   frame.setTitle(title);
   frame.setResizable(true);
   frame.setSize(w,h);
   frame.setClosable(true);
   frame.setMaximizable(true);
   frame.setIconifiable(true);
   frame.setLocation(xOffset*openFrameCount, yOffset*openFrameCount);
   frame.toFront();
   final JMenuItem menuItem = new JMenuItem(title);
   frame.addInternalFrameListener(new javax.swing.event.InternalFrameAdapter()
                                   { public void internalFrameClosed(javax.swing.event.InternalFrameEvent evt)
                                     {
                                       openFrameCount--;
                                       windowMenu.remove(menuItem);
                                     };
                                   });

   menuItem.addActionListener(new ActionListener()
    {
      public void actionPerformed(ActionEvent e)
      {
        try{  frame.setSelected(true);   frame.setIcon(false); }
        catch(java.beans.PropertyVetoException ex){};
      }
    });

   windowMenu.add(menuItem);
 }



 public void inputLocalFileMenuItem_actionPerformed(ActionEvent e)
 {
   JFileChooser chooser = new JFileChooser(jalview.bin.Cache.LAST_DIRECTORY);
   chooser.setDialogTitle("Open local file");
   chooser.setToolTipText("Open");
   int value = chooser.showOpenDialog(this);
   if(value == JFileChooser.APPROVE_OPTION)
   {
     String choice =  chooser.getSelectedFile().getPath();
     jalview.bin.Cache.LAST_DIRECTORY = choice;
     String format = IdentifyFile.Identify(choice, "File");
     LoadFile(choice, "File", format);
   }
 }

 public void LoadFile(String file, String protocol,  String format)
 {
   SequenceI [] sequences = null;

   if (FormatProperties.contains(format))
       sequences = FormatAdapter.read(file, protocol, format);

   if (sequences != null)
   {
     AlignFrame af = new AlignFrame(new Alignment(sequences));
     addInternalFrame(af, file, 700, 500);
     af.statusBar.setText("Successfully loaded file " + file);


   }
   else
     JOptionPane.showInternalMessageDialog(Desktop.desktop,  "Couldn't open file.\n"
                          + "Formats currently supported are\n"
                          + "Fasta, MSF, Clustal, BLC, PIR, MSP or PFAM"
                          ,"Error loading file",
                                   JOptionPane.WARNING_MESSAGE);

 }

 public void inputURLMenuItem_actionPerformed(ActionEvent e)
 {
   String url = JOptionPane.showInternalInputDialog(Desktop.desktop,"Enter url of input file",
                                            "Input alignment from URL",
                                            JOptionPane.QUESTION_MESSAGE);
   if (url == null)
     return;

   String format = IdentifyFile.Identify(url, "URL");

   System.out.println(format +" format");
   if (format.equals("URL NOT FOUND"))
   {
     JOptionPane.showInternalMessageDialog(Desktop.desktop,"Couldn't locate " + url,
                                   "URL not found",
                                   JOptionPane.WARNING_MESSAGE);
     return;
   }

    LoadFile(url, "URL", format);
 }

 public void inputTextboxMenuItem_actionPerformed(ActionEvent e)
 {
   CutAndPasteTransfer cap = new CutAndPasteTransfer(true);
   int accept =  JOptionPane.showInternalOptionDialog(Desktop.desktop, cap, "Cut & paste Alignment File",
                                       JOptionPane.YES_NO_CANCEL_OPTION,
                                       JOptionPane.PLAIN_MESSAGE,
                                       null,
                                       new Object[]{"Accept", "Cancel", }, null);


  if(accept == JOptionPane.YES_OPTION)
  {
    String format = IdentifyFile.Identify(cap.getText(), "Paste");
    SequenceI [] sequences = null;

    if (FormatProperties.contains( format ))
      sequences = FormatAdapter.read(cap.getText(), "Paste", format);


      if(sequences!=null)
      {
        AlignFrame af = new AlignFrame(new Alignment(sequences));
        addInternalFrame(af, "Cut & Paste input - "+format, 700, 500);
        af.statusBar.setText("Successfully pasted alignment file");
      }
      else
        JOptionPane.showInternalMessageDialog(Desktop.desktop, "Couldn't read the pasted text.\n"
                                      +"Formats currently supported are\n"
                                      +"Fasta, MSF, Clustal, BLC, PIR, MSP or PFAM",
                                      "Error parsing text", JOptionPane.WARNING_MESSAGE);


   }
 }

/*
* Exit the program
*/
 public void quit_actionPerformed(ActionEvent e)
 {
   if(jalview.bin.Jalview.applet!=null)
     jalview.bin.Jalview.applet.destroy();
    else
      System.exit(0);
 }


 protected void colourIndexMenuItem_actionPerformed(ActionEvent e)
 {
   ColourKey colourKey = new ColourKey(null);
   addInternalFrame(colourKey, "Colour scheme key", 400, 320);
 }


 public void aboutMenuItem_actionPerformed(ActionEvent e)
 {
   JOptionPane.showInternalMessageDialog(Desktop.desktop,
                                         "JalView 2005"
                                       +"\nAuthors:  Michele Clamp, James Cuff, Steve Searle, Andrew Waterhouse, Jim Procter & Geoff Barton."
                                       +"\nCurrent development managed by Andrew Waterhouse; Barton Group, University of Dundee."
                                       +"\nIf  you use JalView, please cite:  \"Clamp, M., Cuff, J., Searle, S. M. and Barton, G. J. (2004), The Jalview Java Alignment Editor\"",
                                         "About Jalview",
                                         JOptionPane.INFORMATION_MESSAGE);
 }

 public void documentationMenuItem_actionPerformed(ActionEvent e)
 {
   try{
     jalview.util.BrowserLauncher.openURL("http://www.jalview.org/documentation.html");
   }catch(Exception ex){}
 }


}
